==> yfiles_jupyter_graphs-1.0.1.tar.gz: yfiles_jupyter_graphs-1.0.1/LICENSE.md <==
# yWorks GmbH - yFiles Jupyter Graphs Free License

Version 1.0, March 2022

# TERMS AND CONDITIONS FOR USE AND DISTRIBUTION

## DEFINITIONS

**"License"**  shall mean the terms and conditions for use and distribution as defined by this document.

**"Licensor"** shall mean the copyright owner yWorks GmbH that is granting the License.

**"You"** shall mean an individual or legal entity exercising the rights granted by this License.

**"Software"** shall mean yFiles Jupyter Graphs Prebuilt Extension.

**"Jupyter System"** shall refer to both a JupyterLab software system as well as Jupyter Notebook software system.

1. **LICENSE GRANT**

   1.1. **Title.** The Software and all copies thereof are proprietary to Licensor (yWorks GmbH) and title thereto
   remains in Licensor (yWorks GmbH), at all times.

   1.2. **All Use.** You are granted a perpetual, worldwide, non-exclusive, no-charge, royalty-free, non-transferable
   license to install and dynamically use the Software in your browser on top of your Jupyter System on a per-user
   level, provided that the following conditions are met:
    1. **No-Wrapping.** The Software may not be used as part of an automated process or outside of the Jupyter System.
       You may not expose the functionality provided by the Software in a way that enables a third party to use it. This
       especially means that you may not expose an API to a third party that will allow them to access functionality
       provided by the Software.
    2. **No-Reverse-Engineering.** You are not allowed to reverse engineer, decompile, de-obfuscate or otherwise attempt
       to derive the de-obfuscated source code of Software, create derivative works,modify, translate, or disassemble
       the Software, unless and only to the extent that such activity is expressly permitted by applicable lawor by this
       License.
    3. **No-Distribution.** You may not sell, rent, loan, or otherwise encumber or transfer the Software in whole or in
       part, to a third party, except as expressly granted herein. You may not reproduce or redistribute copies of the
       Software in any medium.
    4. **Trademark Notices.** You may not remove, alter, or obscure any confidentiality or proprietary notices (
       including copyright and trademark notices) of yWorks or its suppliers on, in, or displayed by the Software.

   1.3 **License Breach.** If You fail to comply with any term of this License,this License shall be revoked and You
   shall cease use of, and destroy, all copies of the Software.

2. **ANALYTICS FEATURES**

   The Software may include analytics features to analyze data that help Licensor improve the included layout
   algorithms, user experience, and products and services in general. These analytics features may send anonymized usage
   statistics to Licensor, including but not limited to information about what Software features are used and what types
   of graphs are laid out, as well as anonymized graph data, including but not limited to label texts, images, or icons
   that are replaced with placeholder data. The provided data does not contain or associate with any personal
   information, it does not allow to reconstruct the original contents and Licensor does not use them to identify any
   individual patterns of use or behavior.

3. **DISCLAIMER OF WARRANTY**
   Unless required by applicable law or agreed to in writing, Licensor provides the Software on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any
   warranties or conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are
   solely responsible for determining the appropriateness of using the Software and assume any risks associated with
   your exercise of rights under this License.

4. **LIMITATION OF LIABILITY**
   In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless
   required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall Licensor be
   liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any
   character arising as a result of this License or out of the use or inability to use the Software (including but not
   limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other
   commercial damages or losses), even if Licensor has been advised of the possibility of such damages.

5. **APPLICABLE LAW AND COURT OF JURISDICTION**
   This Agreement is made and shall be construed in accordance with the laws of Germany. Court of Jurisdiction is
   Tübingen, Germany.

==> yfiles_jupyter_graphs-1.1.0.tar.gz: yfiles_jupyter_graphs-1.1.0/LICENSE.md <==
# yWorks GmbH - yFiles Graphs for Jupyter Free License

Version 1.1, April 2022

# TERMS AND CONDITIONS FOR USE AND DISTRIBUTION

## DEFINITIONS

**"License"**  shall mean the terms and conditions for use and distribution as defined by this document.

**"Licensor"** shall mean the copyright owner yWorks GmbH that is granting the License.

**"You"** shall mean an individual or legal entity exercising the rights granted by this License.

**"Software"** shall mean yFiles Graphs for Jupyter Prebuilt Extension.

**"Jupyter System"** shall refer to both a JupyterLab software system as well as Jupyter Notebook software system.

1. **LICENSE GRANT**

   1.1. **Title.** The Software and all copies thereof are proprietary to Licensor (yWorks GmbH) and title thereto
   remains in Licensor (yWorks GmbH), at all times.

   1.2. **All Use.** You are granted a perpetual, worldwide, non-exclusive, no-charge, royalty-free, non-transferable
   license to install and dynamically use the Software in your browser on top of your Jupyter System on a per-user
   level, provided that the following conditions are met:
    1. **No-Wrapping.** The Software may not be used as part of an automated process or outside of the Jupyter System.
       You may not expose the functionality provided by the Software in a way that enables a third party to use it. This
       especially means that you may not expose an API to a third party that will allow them to access functionality
       provided by the Software.
   2. **No-Reverse-Engineering.** You are not allowed to reverse engineer, decompile, de-obfuscate or otherwise attempt
      to derive the de-obfuscated source code of Software, create derivative works,modify, translate, or disassemble the
      Software, unless and only to the extent that such activity is expressly permitted by applicable lawor by this
      License.
   3. **No-Distribution.** You may not sell, rent, loan, or otherwise encumber or transfer the Software in whole or in
      part, to a third party, except as expressly granted herein. You may not reproduce or redistribute copies of the
      Software in any medium.
   4. **Trademark Notices.** You may not remove, alter, or obscure any confidentiality or proprietary notices (including
      copyright and trademark notices) of yWorks or its suppliers on, in, or displayed by the Software.

   1.3 **License Breach.** If You fail to comply with any term of this License,this License shall be revoked and You
   shall cease use of, and destroy, all copies of the Software.

2. **ANALYTICS FEATURES**

   The Software may include analytics features to analyze data that help Licensor improve the included layout
   algorithms, user experience, and products and services in general. These analytics features may send anonymized usage
   statistics to Licensor, including but not limited to information about what Software features are used and what types
   of graphs are laid out, as well as anonymized graph data, including but not limited to label texts, images, or icons
   that are replaced with placeholder data. The provided data does not contain or associate with any personal
   information, it does not allow to reconstruct the original contents and Licensor does not use them to identify any
   individual patterns of use or behavior.

3. **DISCLAIMER OF WARRANTY**

   Unless required by applicable law or agreed to in writing, Licensor provides the Software on an "AS IS" BASIS, WITHOUT
   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any warranties or
   conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are solely
   responsible for determining the appropriateness of using the Software and assume any risks associated with your
   exercise of rights under this License.

4. **LIMITATION OF LIABILITY**

   In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless
   required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall Licensor be
   liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any
   character arising as a result of this License or out of the use or inability to use the Software (including but not
   limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other
   commercial damages or losses), even if Licensor has been advised of the possibility of such damages.

5. **APPLICABLE LAW AND COURT OF JURISDICTION**

   This Agreement is made and shall be construed in accordance with the laws of Germany. Court of Jurisdiction is
   Tübingen, Germany.
